@@ -148,8 +148,8 @@ void K3b::IsoImager::slotProcessExited( int exitCode, QProcess::ExitStatus exitS
                     // that contain one or more backslashes
                     // mkisofs 1.14 has the bug, 1.15a40 not
                     // TODO: find out the version that fixed the bug
-                    if( m_containsFilesWithMultibleBackslashes &&
-                        !k3bcore->externalBinManager()->binObject( "mkisofs" )->hasFeature( "backslashed_filenames" ) ) {
+                    if( m_containsFilesWithMultibleBackslashes && d->mkisofsBin &&
+                        !d->mkisofsBin->hasFeature( "backslashed_filenames" ) ) {
                         emit infoMessage( i18n("Due to a bug in mkisofs <= 1.15a40, K3b is unable to handle "
                                                "filenames that contain more than one backslash:"), MessageError );
 
@@ -265,7 +265,7 @@ void K3b::IsoImager::startSizeCalculation()
 
     qDebug() << "***** mkisofs calculate size parameters:";
     QString s = m_process->joinedArgs();
-    qDebug() << s << endl << flush;
+    qDebug() << s << Qt::endl << Qt::flush;
     emit debuggingOutput("mkisofs calculate size command:", s);
 
     // since output changed during mkisofs version changes we grab both
@@ -430,7 +430,7 @@ void K3b::IsoImager::start()
 
     qDebug() << "***** mkisofs parameters:\n";
     QString s = m_process->joinedArgs();
-    qDebug() << s << endl << flush;
+    qDebug() << s << Qt::endl << Qt::flush;
     emit debuggingOutput("mkisofs command:", s);
 
     if( !m_process->start( KProcess::SeparateChannels ) ) {
@@ -556,7 +556,7 @@ bool K3b::IsoImager::addMkisofsParameters( bool printSize )
     int volsetSeqNo = m_doc->isoOptions().volumeSetNumber();
     if( volsetSeqNo > volsetSize ) {
         qDebug() << "(K3b::IsoImager) invalid volume set sequence number: " << volsetSeqNo
-                 << " with volume set size: " << volsetSize << endl;
+                 << " with volume set size: " << volsetSize << Qt::endl;
         volsetSeqNo = volsetSize;
     }
     *m_process << "-volset-size" << QString::number(volsetSize);
@@ -605,7 +605,7 @@ bool K3b::IsoImager::addMkisofsParameters( bool printSize )
     }
 
     if ( filesGreaterThan4Gb ) {
-        if ( !d->mkisofsBin->hasFeature( "no-4gb-limit" ) ) {
+        if ( d->mkisofsBin && !d->mkisofsBin->hasFeature( "no-4gb-limit" ) ) {
             emit infoMessage( i18n( "Found files bigger than 4 GB. K3b needs at least %1 to continue." ,
                               QString( "mkisofs >= 2.01.01a33 / genisoimage >= 1.1.4" ) ),
                               MessageError );
@@ -614,7 +614,7 @@ bool K3b::IsoImager::addMkisofsParameters( bool printSize )
     }
 
     // in genisoimage 1.1.3 "they" silently introduced this awful parameter
-    if (filesGreaterThan2Gb && d->mkisofsBin->hasFeature("genisoimage") && d->mkisofsBin->version() >= K3b::Version(1, 1, 3)) {
+    if (filesGreaterThan2Gb && d->mkisofsBin && d->mkisofsBin->hasFeature("genisoimage") && d->mkisofsBin->version() >= K3b::Version(1, 1, 3)) {
         *m_process << "-allow-limited-size";
         emit infoMessage(i18n("Found files bigger than 2 GB. These files will be fully accessible."),
                 MessageInfo);
@@ -710,9 +710,12 @@ bool K3b::IsoImager::addMkisofsParameters( bool printSize )
 
 
     // additional parameters from config
-    const QStringList& params = k3bcore->externalBinManager()->binObject( "mkisofs" )->userParameters();
-    for( QStringList::const_iterator it = params.begin(); it != params.end(); ++it )
-        *m_process << *it;
+    
+    if ( d->mkisofsBin) {
+        const QStringList& params = d->mkisofsBin->userParameters();
+        for( QStringList::const_iterator it = params.begin(); it != params.end(); ++it )
+            *m_process << *it;
+    }
 
     return true;
 }
@@ -857,7 +860,7 @@ bool K3b::IsoImager::writeRRHideFile()
     while( item ) {
         if( item->hideOnRockRidge() ) {
             if( !item->isDir() )  // hiding directories does not work (all dirs point to the dummy-dir)
-                s << escapeGraftPoint( item->localPath() ) << endl;
+                s << escapeGraftPoint( item->localPath() ) << Qt::endl;
         }
         item = item->nextSibling();
     }
@@ -878,7 +881,7 @@ bool K3b::IsoImager::writeJolietHideFile()
     while( item ) {
         if( item->hideOnRockRidge() ) {
             if( !item->isDir() )  // hiding directories does not work (all dirs point to the dummy-dir but we could introduce a second hidden dummy dir)
-                s << escapeGraftPoint( item->localPath() ) << endl;
+                s << escapeGraftPoint( item->localPath() ) << Qt::endl;
         }
         item = item->nextSibling();
     }
@@ -904,17 +907,17 @@ bool K3b::IsoImager::writeSortWeightFile()
     while( (item = item->nextSibling()) ) {  // we skip the root here
         if( item->sortWeight() != 0 ) {
             if( m_doc->bootImages().contains( dynamic_cast<K3b::BootItem*>(item) ) ) { // boot-image-backup-hack
-                s << escapeGraftPoint( static_cast<K3b::BootItem*>(item)->tempPath() ) << " " << item->sortWeight() << endl;
+                s << escapeGraftPoint( static_cast<K3b::BootItem*>(item)->tempPath() ) << " " << item->sortWeight() << Qt::endl;
             }
             else if( item->isDir() ) {
                 //
                 // Since we use dummy dirs for all directories in the filesystem and mkisofs uses the local path
                 // for sorting we need to create a different dummy dir for every sort weight value.
                 //
-                s << escapeGraftPoint( dummyDir( static_cast<K3b::DirItem*>(item) ) ) << " " << item->sortWeight() << endl;
+                s << escapeGraftPoint( dummyDir( static_cast<K3b::DirItem*>(item) ) ) << " " << item->sortWeight() << Qt::endl;
             }
             else
-                s << escapeGraftPoint( item->localPath() ) << " " << item->sortWeight() << endl;
+                s << escapeGraftPoint( item->localPath() ) << " " << item->sortWeight() << Qt::endl;
         }
     }
 
